@@ -1,7 +1,7 @@
 see.accPrec.tck <- function(){
 
-require(plotrix)
-require(tcltk) || stop("tcltk support is absent")
+
+
     if (!exists("slider.env")) 
         slider.env <- NULL
     suppressWarnings(rm(slider.env))
